@@ -1,7 +1,7 @@
 #' Crea el esquema SQL
 #' @noRd
 create_schema <- function() {
-  con <- censo_bbdd()
+  con <- censo_conectar()
   
   # comunas ----
   
